///////////////////////////////////////////////////////////////////
// The Init function is called when bric is first selected       //
// Use it to make changes to the initial state of the sidebar UI //
///////////////////////////////////////////////////////////////////

var targetImg = 0;

function init(bricVersion)
{
	var targetItem = $('editarea img').eq(targetImg);
	var imgPath = $('editarea img').eq(targetImg).attr('src');
	var imgPathX2 = '';
	var imgPathX3 = '';
	
	if(targetItem.hasAttr('src-2')) // Has @2x Image Set
	{
		imgPathX2 = targetItem.attr('src-2');
	}
	
	if(targetItem.hasAttr('src-3')) // Has @3x Image Set
	{
		imgPathX3 = targetItem.attr('src-3');
	}
	
	// Set Dropdown menu items to current gallery image count
	window.webkit.messageHandlers.popUIMenu.postMessage('{"attr":"target-edit-img","items":"'+generateNewMenuString()+'", "value":"'+targetImg+'"}');
	
	// Set Image thumbnail
	window.webkit.messageHandlers.setUIVal.postMessage('{"attr":"current-edit-img","value":"'+imgPath+'","sync":"false","imageRes":"1","image2x":"'+imgPathX2+'","image3x":"'+imgPathX3+'"}'); 
}


//////////////////////
// Custom Functions //
//////////////////////


// Set Target Image
function setTargetEditImg(selectIdx)
{
	// If the Selected index coming in is greator than the number of gallery images then the 'Add new Image' option was selected.
	var imgCount = $('editarea img').length-1;
	
	if(selectIdx > imgCount) // Add New Image
	{
		targetImg = imgCount+1;

		// Add Image Item To HTML
		$('editarea .masonry-gallery').append('<a href="#" data-lightbox="img/placeholder-image.png" data-gallery-id="masonry-gallery" data-caption=""><img src="img/placeholder-image.png" alt=""></a>');
		window.webkit.messageHandlers.sync.postMessage("changes"); // Sync Changes
		
		// Update Dropdown Menu Items
		window.webkit.messageHandlers.popUIMenu.postMessage('{"attr":"target-edit-img","items":"'+generateNewMenuString()+'", "value":"'+targetImg+'"}');
	}
	else // Select Current Image
	{
		targetImg = selectIdx; // Set Traget Image
	}
	
	// Drop down value has changed 
	// so lets set the sidebar UI to the target Image data
	setSidebarUIForCurrentItem();
}

// Set Sidebar UI
function setSidebarUIForCurrentItem()
{
	var imgItem = $('editarea img').eq(targetImg); // Get Traget Image

	// Set Sidebar Thumbnail
	var imgPath = imgItem.attr('src');
	var imgPathX2 = '';
	var imgPathX3 = '';
	
	if(imgItem.hasAttr('src-2')) // Has @2x Image Set
	{
		imgPathX2 = imgItem.attr('src-2');
	}
	
	if(imgItem.hasAttr('src-3')) // Has @3x Image Set
	{
		imgPathX3 = imgItem.attr('src-3');
	}
	
	window.webkit.messageHandlers.setUIVal.postMessage('{"attr":"current-edit-img","value":"'+imgPath+'","sync":"false","imageRes":"1","image2x":"'+imgPathX2+'","image3x":"'+imgPathX3+'"}'); 

	// Set Sidebar Alt Text Field
	var imgAltVal = imgItem.attr('alt');
	window.webkit.messageHandlers.setUIVal.postMessage('{"attr":"gallery-img-alt-text","value":"'+imgAltVal+'","sync":"false"}');
	
	// Set Caption Text Field
	var imgCaptionVal = imgItem.parent().attr('data-caption');
	window.webkit.messageHandlers.setUIVal.postMessage('{"attr":"img-caption","value":"'+imgCaptionVal+'","sync":"false"}');
}



// Set Image Path
function setImagePath(imgPath,imgRes)
{
	if(imgRes == 1) // @1x
	{
		var fileName = imgPath.substring(imgPath.lastIndexOf('/')+1).replace(/%20/g,' ');
		$('editarea img').eq(targetImg).attr('src',imgPath);
		$('editarea img').eq(targetImg).parent().attr('data-lightbox','img/'+fileName);
	}
	else // @2x & @3x
	{
		setHighResImg(imgPath,imgRes);
	}
	
	window.webkit.messageHandlers.sync.postMessage("changes"); // Sync Changes
}

// Set High Res image
function setHighResImg(imgPath,imgRes)
{	
	// Dont store actual paths to assets for multi res as they 
	// are not used within Blocs, srcset paths should be set 
	// up for use on export ie. img/myimage.png and 
	// full paths stored to src-2 & src-3 helper attributes which are used 
	// within design enviroment.
	
	var fileName = getFileExportName(imgPath); // Get Image File Name	
	var imgItem = $('editarea img').eq(targetImg);
	var srcSetData = imgItem.attr('srcset-blocsapp'); // Retina SRC Data
	var newData = fileName+' '+imgRes+'x';
	
	if(imgRes == 2) // @2x
	{
		if(imgItem.hasAttr('src-3')) // Has @3x Value
		{
			newData += ', '+getFileExportName(imgItem.attr('src-3'))+' 3x';
		}
	}
	else // @3x
	{
		if(imgItem.hasAttr('src-2')) // Has @3x Value
		{
			newData = getFileExportName(imgItem.attr('src-2'))+' 2x, '+ newData;
		}
	}
	
	imgItem.attr('srcset-blocsapp',newData).attr("src-"+imgRes, imgPath); // Set Image
	
	// src-2, src-3 are helper attributes which are used to store the paths 
	// in the design enviroment, these attributes are removed when project is exported. 
}

// Get Image File Export Name
function getFileExportName(imgPath)
{	
	var fileName = 'img/'+imgPath.split('/').pop();
	
	if(imgPath.substring(0,4) == 'http')
	{
		fileName = imgPath;
	}
	
	return fileName;
}


// Set Image Alt Text
function setImageAltText(V)
{
	$('editarea img').eq(targetImg).attr('alt',V);
	window.webkit.messageHandlers.sync.postMessage("changes"); // Sync Changes
}

// Set Image Caption Text
function setImgCaption(V)
{
	$('editarea img').eq(targetImg).parent().attr('data-caption',V);
	window.webkit.messageHandlers.sync.postMessage("changes"); // Sync Changes
}

// Remove Image
function removeImg()
{
	var imgCount = $('editarea img').length;
	
	if(imgCount > 1) // Prevent removing all images
	{
		$('editarea img').eq(targetImg).parent().remove();
		window.webkit.messageHandlers.sync.postMessage("changes"); // Sync Changes
		
		// Refresh Sidebar UI
		targetImg = 0;
		setSidebarUIForCurrentItem();
		window.webkit.messageHandlers.popUIMenu.postMessage('{"attr":"target-edit-img","items":"'+generateNewMenuString()+'", "value":"'+targetImg+'"}');	 // Update dropdown menu
	}
	else // Notify User no more images can be removed
	{
		window.webkit.messageHandlers.alert.postMessage('Sorry this gallery Bric requires at least one image in it.');
	}
}



// Generate New Menu String
function generateNewMenuString()
{
	var menuItems = '';
	
	$('editarea img').each(function(i) // Loop all Images
	{
		var idx = i+1;
		menuItems += 'Image '+idx+',';
	});
	
	return menuItems + '*seperator*,Add Image';
}


/////////////
// Plugins //
/////////////


// Has Attribute
$.fn.hasAttr = function(name){  
   return this.attr(name) !== undefined;
};