//*******************************************************************************
// Column Control
//*******************************************************************************


// Automatically Set The Column Width Based On Flex
function autoSetColumnWidthFromFlex()
{
	var breakPoint = getBreakPointSize();
	var columPercent = getColumnWidthPercentValue();
	var colNumber = Math.round(12/(100/columPercent));
	var colClass = 'col'+breakPoint+'-'+colNumber;
	TIO.addClass(colClass);
}


// Get Column Width Percentage
function getColumnWidthPercentValue()
{
	var widthClass = getColumnLayoutClass('col');
	var columnWidth = TIO.outerWidth();
	var rowWidth = TIO.parent().outerWidth();	
	return  calculatePercentage(columnWidth,rowWidth);
}

// Set Column Width
function setColumnWidth(widthVal)
{
	SDCS('Column Content Width'); // Save document current state
	processSetColumnWidth(widthVal)
	SUDS('Column Content Width');
}

// Set Column Width
function processSetColumnWidth(widthVal)
{
	var widthClass = getColumnLayoutClass('col');
	var breakPoint = getBreakPointSize();
	var columnNumber = 0;
	var allowWidth = false;

	if (widthClass != 'none') // Has Offset
	{
		columnNumber = widthClass.replace(/\D/g,''); // Get column number
	}

	if (widthVal == 0 && widthClass.indexOf(breakPoint) !=-1) // Set Flex Width (inherit)
	{
		allowWidth = true;
		TIO.removeClass(widthClass).addClass('col');
	}
	else if (widthVal == 1) // Decrease Width
	{
		if (columnNumber > 1)
		{
			columnNumber--;
			TIO.removeClass('col').addClass('col'+breakPoint+'-'+columnNumber);
			allowWidth = true;
			
			if (breakPoint.length > 0 && widthClass.indexOf(breakPoint) !=-1 || breakPoint.length == 0) // The effecting class is for the current breakpoint
			{
				TIO.removeClass(widthClass);
			}
		}
	}
	else if (widthVal == 2) // Increase Width
	{
		if (columnNumber < 12)
		{
			columnNumber++;
			TIO.removeClass('col').addClass('col'+breakPoint+'-'+columnNumber);
			allowWidth = true;
			
			if (breakPoint.length > 0 && widthClass.indexOf(breakPoint) !=-1 || breakPoint.length == 0) // The effecting class is for the current breakpoint
			{
				TIO.removeClass(widthClass);
			}
		}
	}
	
	if (!allowWidth) // Width not available
	{
		window.webkit.messageHandlers.playSound.postMessage('Funk');
	}
	TIO.click();
}

// Set Column Offset
function setColumnOffset(offSetVal)
{
	SDCS('Column Content Offset'); // Save document current state
	processSetColumnOffset(offSetVal);
	SUDS('Column Content Offset');
}

// Process Set Column Offset
function processSetColumnOffset(offSetVal)
{
	var offsetClass = getColumnLayoutClass('offset');
	var breakPoint = getBreakPointSize();
	var columnNumber = 0;
	var allowOffset = false;

	if (offsetClass != 'none') // Has Offset
	{
		columnNumber = offsetClass.replace(/\D/g,''); // Get column number
	}

	if (offSetVal == 0) // Remove Offset
	{
		allowOffset = true;
		TIO.removeClass(offsetClass);
	}
	else if (offSetVal == 1) // Decrease Offset
	{
		if (columnNumber > -1)
		{
			columnNumber--;
			TIO.addClass('offset'+breakPoint+'-'+columnNumber);
			allowOffset = true;
			
			if (breakPoint.length > 0 && offsetClass.indexOf(breakPoint) !=-1 || breakPoint.length == 0) // The effecting class is for the current breakpoint
			{
				TIO.removeClass(offsetClass);
			}
		}
	}
	else if (offSetVal == 2) // Increase Offset
	{
		if (columnNumber < 11)
		{
			columnNumber++;
			TIO.addClass('offset'+breakPoint+'-'+columnNumber);
			allowOffset = true;
			
			if (breakPoint.length > 0 && offsetClass.indexOf(breakPoint) !=-1 || breakPoint.length == 0) // The effecting class is for the current breakpoint
			{
				TIO.removeClass(offsetClass);
			}
		}
	}
	
	if (!allowOffset) // Offset not available
	{
		window.webkit.messageHandlers.playSound.postMessage('Funk');
	}
	TIO.click();
}

// Set Column Order
function setColumnOrder(orderVal)
{
	SDCS('Column Content Order'); // Save document current state
	
	var orderClass = getColumnLayoutClass('order');
	var breakPoint = getBreakPointSize();
	var columnCount = TIO.closest('.row').children().length;
	var orderNumber = 0;
	var allowOrder = false;
	
	if (orderClass != 'none') // Has Order
	{
		orderNumber = orderClass.replace(/\D/g,''); // Get order number
	}

	if (orderVal == 0) // Remove Order
	{
		allowOrder = true;
		TIO.removeClass(orderClass);
	}
	else if (orderVal == 1) // Decrease Order
	{
		if (orderNumber > -1)
		{
			orderNumber--;
			TIO.addClass('order'+breakPoint+'-'+orderNumber);
			allowOrder = true;
			
			if (breakPoint.length > 0 && orderClass.indexOf(breakPoint) !=-1 || breakPoint.length == 0) // The effecting class is for the current breakpoint
			{
				TIO.removeClass(orderClass);
			}
		}
	}
	else if (orderVal == 2) // Increase Order
	{
		if (orderNumber < columnCount)
		{
			if (orderNumber < 11)
			{
				orderNumber++;
				TIO.addClass('order'+breakPoint+'-'+orderNumber);
				allowOrder = true;
			}
			
			if (breakPoint.length > 0 && orderClass.indexOf(breakPoint) !=-1 || breakPoint.length == 0) // The effecting class is for the current breakpoint
			{
				TIO.removeClass(orderClass);
			}
		}
	}
	
	if (!allowOrder) // Order not available
	{
		window.webkit.messageHandlers.playSound.postMessage('Funk');
	}
	TIO.click();
	SUDS('Column Content Order');
}


// Get Column Layout Class
function getColumnLayoutClass(targetClass)
{
	var className = 'none';
	var breakPoint = getBreakPointSize();
	var foundClass = false;
	
	if (TIO.is('.row [class^="'+targetClass+breakPoint+'-"], .row [class*=" '+targetClass+breakPoint+'-"]')) // Has width class for breakpoint
	{
		foundClass = true;
	}
	else // Didnt find match so look at lower levels effecting this level
	{
		for (i = 0; i < 3; i++) // Loop 3 times
		{
			breakPoint = getNextBreakPointDown(breakPoint);

			if (TIO.is('.row [class^="'+targetClass+breakPoint+'-"], .row [class*=" '+targetClass+breakPoint+'-"]')) // Has width class for breakpoint
			{
				foundClass = true;	
				break; // End Loop
			}
		}
	}

	if (foundClass) // Has width class for breakpoint
	{
		var classData = cleanColumnClassData();
		
		if (breakPoint.length == 0 && classData.indexOf(' ') !=-1) // Xtra Small Breakpoints Additional Check
		{
			var classDataArray = classData.split(' ');
			
			for (var i= classDataArray.length; i--; ) // Loop Array and remove other breakpoint classes
			{
				var className = classDataArray[i];
	
				if (className.indexOf('-sm-') !=-1 || className.indexOf('-md-') !=-1 || className.indexOf('-lg-') !=-1 || className.indexOf('-xl-') !=-1)
				{
					classDataArray.splice(i, 1);
				}
			}
		
			classData = classDataArray.join(' ');

			if (classData.indexOf(targetClass+breakPoint) == -1) // Didnt find Class
			{
				return className = 'none';
			}
		}
		
		className = classData.substring(classData.indexOf(targetClass+breakPoint+'-'));
		
		if (className.indexOf(' ') !=-1) // Has space so trim class
		{
			className = className.substring(0,className.indexOf(' '));
		}
	}
	
	return className;
}

// Set Row Column Count
function setNumberOfColumns(newColValue)
{
	var columnCount = TIO.children('.row [class^="col"], .row [class*=" col"]').length; // Row column count
	var colsToAdd = newColValue - columnCount; // Number of columns to add
	var colsToRemove = columnCount - newColValue; // Number of columns to remove
	var removeCounter = colsToRemove //  Number counter used for deletion
	
	SDCS('Row Column Count'); // Save document current state
	
	if (newColValue != columnCount) // If number of columns is different to current then change
	{
		if (newColValue > columnCount) // Add Columns
		{
			// Create additional divs
			for (var i = 0, l = colsToAdd; i < l; i++ )
			{
			     TIO.append(col_empty);
			}
		}
		else // remove Columns
		{
			// First remove empty columns
			for (var i = 0, l = colsToRemove; i < l; i++ )
			{ 
				 if (TIO.find('.empty-column').length)
				 {
					TIO.find('.empty-column').eq(0).parent().remove();
				 	removeCounter --; // Lower the number of columns to remove
				 }
			}
			
			// No empty columns left so removed filled ones
			if (TIO.children().length > newColValue)
			{
				for (var i = 0, l = removeCounter; i < l; i++)
				{
				     TIO.children().eq(i).remove();
				}
			}	
		}
	}
	SUDS('Row Column Count');
	populateLayerTree(true);
	AEOM();
}