//*******************************************************************************
// WebFont controller
//*******************************************************************************

window.googleFonts = [];

$(document).ready(function()
{
	setUpFonts();
	setUpArrowKeyNavigation();
	$('body').on('contextmenu', function(){return false;}); // Prevent Context Menu
});

// Web font dropdown setup
function setUpFonts()
{	
	window.webkit.messageHandlers.loadFont.postMessage(''); // Load Google Font Array	
}
		
// Populate WebFont Array
function populateWebFontArray(D)
{
	googleFonts = D.split('/,/');
}

// Load Web Fonts
function loadWebFonts()
{
	Gfonts = googleFonts;
	
	WebFontConfig = {
	      google: { families:Gfonts }
	   };

	   (function(d)
	   {
	      var wf = d.createElement('script'), s = d.scripts[0];
	      wf.src = 'https://ajax.googleapis.com/ajax/libs/webfont/1.6.26/webfont.js';
	      wf.async = true;
	      s.parentNode.insertBefore(wf, s);		  
	   })(document);

	for( var i = 0; i < Gfonts.length; i++)
	{	
		var CFN = cleanFontName(Gfonts[i]); // Clean font name
		var fontStyle = 'font-family:'+CFN;
		
		if(CFN.indexOf(':') !=-1) // Has Weight
		{
			var fontWeight = CFN.substring(CFN.indexOf(':')+1);
			var fontName = CFN.substring(0,CFN.indexOf(':'));
			fontStyle= 'font-family:'+fontName+';font-weight:'+fontWeight+';';
		}

		var fontName = CFN.replace(/"/g,'')
	
		$('#webFontList').append("<li class=\"google hosted\" data-family='"+fontName+"' style='"+fontStyle+"'>"+fontName+"</li>");
	}

	$('#webFontList').append("<li id=\"helvetica\" data-family=\"Helvetica\" class=\"local\" style='font-family:&quot;helvetica&quot;;'>Helvetica</li>"); // Add Helvetica 
	
	fontSelectionHandler(); // Set Up Selection Handler
}

// Order Font list
function orderFontList()
{
	var mylist = $('#webFontList');
	var listitems = mylist.children('li').get();
	listitems.sort(function(a, b) {
	   return $(a).text().toUpperCase().localeCompare($(b).text().toUpperCase());
	})
	$.each(listitems, function(idx, itm) { mylist.append(itm); });
}

// Clean Font Name
function cleanFontName(fontName)
{
	fontName = fontName.replace(/\+/g," "); // Add Spaces
	
	var subSetArray = ['arabic','bengali','cyrillic-ext','cyrillic','devanagari','greek-ext','greek','gujarati','gurmukhi','bengali','hebrew','kannada','khmer','latin-ext','malayalam','oriya','sinhala','tamil','telugu','thai','vietnamese'];
	$.each(subSetArray, function(i, subSetName) // Loop Subset Array
	{ 
		fontName = fontName.replace(':'+subSetName,'').replace(','+subSetName,''); // Remove SubSet Names
	});
	
	if(fontName.indexOf(' ') !=-1) // Has Spaces
	{
		var familyName = fontName;
		
		if(familyName.indexOf(':') !=-1) // Has Weight
		{
			familyName = familyName.substring(0,familyName.indexOf(':'));
		}
		fontName = fontName.replace(familyName,'\"'+familyName+'\"');
	}
	
	return fontName
}

// Set Up Selection Handler
function fontSelectionHandler()
{
	// Global typeface selector
   	$('#webFontList').on('click','li', function()
   	{
		var styleValue = $(this).attr('style').replace('font-family:','').replace('font-weight','').replace(/;/g,'');
		window.webkit.messageHandlers.selectFont.postMessage(styleValue);
	});
}

// Toggle WebFonts
function toggleHostedFonts(enable)
{
	if(enable) // Enable Hosted Fonts
	{
		$('.disable-font').removeClass('disable-font');
	}
	else // Disable Hosted Fonts
	{
		$('#webFontList li').each(function() // Loop Web Font Items
		{
			if($(this).hasClass('hosted')) // Get Hosted Fonts and Disable
			{
				$(this).addClass('disable-font');
			}
		});	
	}
}

// Hide Google WebFonts
function hideGoogleFonts(enable)
{
	if(enable) // Enable Hosted Fonts
	{
		$('.hide-font').removeClass('hide-font');
	}
	else // Disable Hosted Fonts
	{
		$('#webFontList li').each(function() // Loop Web Font Items
		{
			if($(this).hasClass('hosted')) // Get Hosted Fonts and Disable
			{
				$(this).addClass('hide-font');
			}
		});	
	}
}


//*******************************************************************************
// Arrow Key Navigation
//*******************************************************************************


function setUpArrowKeyNavigation()
{	
	$(window).on('keydown', function(e)
	{
		e.preventDefault();
		var fontItems = $('#webFontList > li');
		var selectedItem = $('.selected');

	    if (e.which === 40) // Down Arrow
	    {
	        if (selectedItem.length > 0) // Has Selected Item
	        {
	            var next = selectedItem.nextAll('li:visible').first();

	            if (next.length > 0) // Has Next Item
	            {
	            	selectedItem.removeClass('selected');
	                next.addClass('selected');
	            }
	        }
	        else // No Selected Item
	        {
	            fontItems.eq(0).addClass('selected');
	        }

	        if (($(window).scrollTop()+$(window).height()-10) < $('.selected').offset().top)
	    	{
				$(window).scrollTop($('.selected').offset().top);
	    	}
	    }
	    else if (e.which === 38) // Up Arrow
	    {
	        if (selectedItem.length > 0) // Has Selected Item
	        {
	            var prev = selectedItem.prevAll('li:visible').first();

	            if (prev.length > 0) // Has Previous Item
	            {
	            	selectedItem.removeClass('selected');
	            	prev.addClass('selected');
	            }
	        }

	        if ($(window).scrollTop() > $('.selected').offset().top)
	    	{
				$(window).scrollTop($('.selected').offset().top);
	    	}
	    }
	    else if  (e.which === 13) // Return Hit
	    {
	    	$('.selected').click();
	    }
	});
}


//*******************************************************************************
// Set currently Selected Font
//*******************************************************************************


function setCurrentActiveFont(selectedFontName)
{
	$('.selected').removeClass('selected');
	$('#webFontList li[data-family="'+selectedFontName+'"]').addClass('selected');
	$(window).scrollTop($('.selected').offset().top);
}


//*******************************************************************************
// Search Filter Assets Within Group
//*******************************************************************************


function filterFonts(V)
{
	$('#webFontList li').each(function() // Loop all fonts
	{	
		if (V.length > 0) // Search Value Valid
		{	
			$(this).addClass('filter-hide').removeClass('match');
			if ($(this).text().toLowerCase().indexOf(V) != -1 && !$(this).hasClass('.hide-font')) // Found Match
			{
				$(this).removeClass('filter-hide').addClass('match'); // Show Matched Item
			}
		}
		else
		{
			$(this).removeClass('filter-hide'); // Show all in Group
		}
	});

	var matches = $('.match').length;
	window.webkit.messageHandlers.resizeWindow.postMessage(matches);

	// Toggle No Results Label
	$('.no-match-label').hide();
	if (matches == 0)
	{
		$('.no-match-label').show();
	}
	else // Has Results
	{
		var firstResult = $('.match').first();
		$(window).scrollTop(firstResult.offset().top);
	}
}

// Reset Search Filter
function resetSearchFilter()
{
	$('.filter-hide').removeClass('filter-hide');
}
